@@ -1,8 +1,8 @@
 #!/bin/bash
 
 # we have to let R know where the Rcpp header and library are
-export PKG_CPPFLAGS=`r -e "Rcpp:::CxxFlags()"`
-export PKG_LIBS=`r -e "Rcpp:::LdFlags()"`
+export PKG_CPPFLAGS=`Rscript -e "Rcpp:::CxxFlags()"`
+export PKG_LIBS=`Rscript -e "Rcpp:::LdFlags()"`
 
 # build the shared library
 R CMD SHLIB RcppFunctionCallExample.cpp 
