@@ -82,6 +82,7 @@ namespace Rcpp{
 #include <algorithm>
 #include <complex>
 #include <limits.h>
+#include <typeinfo>
 
 #ifdef HAS_INIT_LISTS
 #include <initializer_list>
@@ -113,6 +114,8 @@ std::string demangle( const std::string& name) ;
 #define R_2_12_0
 #endif
 
+#include <Rcpp/complex.h>
+
 // #ifdef BUILDING_DLL
 // #define RcppExport extern "C" __declspec(dllexport)
 // #else
@@ -195,9 +198,13 @@ namespace Rcpp{
 #endif
 
 #if RCPP_DEBUG_LEVEL > 0
-	#define RCPP_DEBUG( fmt , ... ) Rprintf( "%s:%d " fmt "\n" , __FILE__, __LINE__,##__VA_ARGS__ ) ;
+	#define RCPP_DEBUG( MSG ) Rprintf( "%s:%d %s" , __FILE__, __LINE__, MSG ) ;
+	#define RCPP_DEBUG_1( fmt, MSG ) Rprintf( "%s:%d " fmt "%s" , __FILE__, __LINE__, MSG ) ;
+	#define RCPP_DEBUG_2( fmt, M1, M2 ) Rprintf( "%s:%d " fmt "%s" , __FILE__, __LINE__, M1, M2 ) ;
 #else
-	#define RCPP_DEBUG( fmt , ... )
+	#define RCPP_DEBUG( MSG )
+	#define RCPP_DEBUG_1( fmt, MSG )
+	#define RCPP_DEBUG_2( fmt, M1, M2 )
 #endif
 
 SEXP stack_trace( const char *file, int line) ;
@@ -223,6 +230,7 @@ SEXP stack_trace( const char *file, int line) ;
 #include <Rcpp/traits/is_convertible.h>
 #include <Rcpp/traits/has_iterator.h>
 #include <Rcpp/traits/expands_to_logical.h>
+#include <Rcpp/traits/matrix_interface.h>
 #include <Rcpp/traits/has_na.h>
 #include <Rcpp/traits/storage_type.h>
 #include <Rcpp/traits/r_sexptype_traits.h>
@@ -230,6 +238,7 @@ SEXP stack_trace( const char *file, int line) ;
 #include <Rcpp/traits/r_type_traits.h>
 #include <Rcpp/traits/wrap_type_traits.h>
 #include <Rcpp/traits/is_na.h>
+#include <Rcpp/traits/if_.h>
 #include <Rcpp/traits/get_na.h>
 #include <Rcpp/traits/is_trivial.h>
 #include <Rcpp/traits/init_type.h>
@@ -241,6 +250,8 @@ SEXP stack_trace( const char *file, int line) ;
 #include <Rcpp/traits/remove_const_and_reference.h>
 #include <Rcpp/traits/result_of.h>
 
+#include <Rcpp/Generator.h>
+
 #include <Rcpp/internal/caster.h>
 #include <Rcpp/internal/r_vector.h>
 #include <Rcpp/r_cast.h>
@@ -254,6 +265,10 @@ SEXP stack_trace( const char *file, int line) ;
 #include <Rcpp/traits/Exporter.h>
 #include <Rcpp/internal/r_coerce.h>
 #include <Rcpp/as.h>
+
+#include <Rcpp/vector/VectorBase.h>
+#include <Rcpp/vector/MatrixBase.h>
+
 #include <Rcpp/internal/wrap.h>
 
 #include <Rcpp/internal/ListInitialization.h>
@@ -265,8 +280,6 @@ RcppExport SEXP RcppXPtrExample_get_external_pointer(SEXP );
 #include <Rcpp/preprocessor.h>
 #include <Rcpp/algo.h>
 
-#include <Rcpp/vector/VectorBase.h>
-
 #include <Rcpp/sugar/sugar_forward.h>
 
 #endif
