@@ -473,10 +473,25 @@
 				'
 					ComplexVector cx( x );
 					return List::create( 
-						_["Re"] = Re( cx ), 
-						_["Im"] = Im( cx ), 
-						_["Conj"] = Conj( cx ), 
-						_["Mod"] = Mod( cx )
+						_["Re"]    = Re( cx ), 
+						_["Im"]    = Im( cx ), 
+						_["Conj"]  = Conj( cx ), 
+						_["Mod"]   = Mod( cx ), 
+						_["exp"]   = exp( cx ), 
+						_["log"]   = log( cx ), 
+						_["sqrt"]  = sqrt( cx ), 
+						_["cos"]   = cos( cx ), 
+						_["sin"]   = sin( cx ), 
+						_["tan"]   = tan( cx ), 
+						_["acos"]  = acos( cx ), 
+						_["asin"]  = asin( cx ), 
+						_["atan"]  = atan( cx ), 
+						// _["acosh"] = acosh( cx ), 
+						_["asinh"] = asinh( cx ), 
+						_["atanh"] = atanh( cx ), 
+						_["cosh"]  = cosh( cx ), 
+						_["sinh"]  = sinh( cx ), 
+						_["tanh"]  = tanh( cx )
 						) ;
 				'
 			), 
@@ -549,7 +564,87 @@
 						diag( outer( xx, xx, std::plus<double>() ) )
 						) ;
 				'
-			)
+			), 
+			"runit_gamma" = list( 
+			signature(x = "numeric" ), 
+			' 
+				NumericVector xx(x) ;
+				return List::create(
+					_["gamma"]      = gamma(xx), 
+					_["lgamma"]     = lgamma(xx),
+					_["digamma"]    = digamma(xx),
+					_["trigamma"]   = trigamma(xx), 
+					_["tetragamma"] = tetragamma(xx), 
+					_["pentagamma"] = pentagamma(xx), 
+					_["factorial"]  = factorial(xx), 
+					_["lfactorial"] = lfactorial(xx)
+					) ;
+			'), 
+			"runit_choose" = list( 
+			signature(n = "numeric", k = "numeric" ), 
+			' 
+				NumericVector nn(n), kk(k) ;
+				return List::create(
+					_["VV"] = choose(nn,kk), 
+					_["PV"] = choose(10.0, kk ), 
+					_["VP"] = choose(nn, 5.0 )
+					) ;
+			'
+			), 
+			"runit_lchoose" = list( 
+			signature(n = "numeric", k = "numeric" ), 
+			' 
+				NumericVector nn(n), kk(k) ;
+				return List::create(
+					_["VV"] = lchoose(nn,kk), 
+					_["PV"] = lchoose(10.0, kk ), 
+					_["VP"] = lchoose(nn, 5.0 )
+					) ;
+			'
+			),
+			"runit_beta" = list( 
+			signature(n = "numeric", k = "numeric" ), 
+			' 
+				NumericVector nn(n), kk(k) ;
+				return List::create(
+					_["VV"] = beta(nn,kk), 
+					_["PV"] = beta(10.0, kk ), 
+					_["VP"] = beta(nn, 5.0 )
+					) ;
+			'
+			),
+			"runit_psigamma" = list( 
+			signature(n = "numeric", k = "numeric" ), 
+			' 
+				NumericVector nn(n), kk(k) ;
+				return List::create(
+					_["VV"] = psigamma(nn,kk), 
+					_["PV"] = psigamma(10.0, kk ), 
+					_["VP"] = psigamma(nn, 5.0 )
+					) ;
+			'
+			),
+			"runit_lbeta" = list( 
+			signature(n = "numeric", k = "numeric" ), 
+			' 
+				NumericVector nn(n), kk(k) ;
+				return List::create(
+					_["VV"] = lbeta(nn,kk), 
+					_["PV"] = lbeta(10.0, kk ), 
+					_["VP"] = lbeta(nn, 5.0 )
+					) ;
+			'
+			), 
+			"runit_log1p" = list( 
+			signature(x = "numeric" ), 
+			' 
+				NumericVector xx(x) ;
+				return List::create(
+					_["log1p"] = log1p(xx), 
+					_["expm1"] = expm1(xx)
+					) ;
+			'
+			) 
 		)
 		
 		signatures <- lapply( sugar.functions, "[[", 1L )
@@ -985,14 +1080,30 @@ test.sugar.wrap <- function( ){
 
 
 test.sugar.complex <- function( ){
-	x <- rnorm(10) + 1i*rnorm(10)
+	x <- c( rnorm(10), NA ) + 1i*c( rnorm(10), NA )
 	fx <- .rcpp.sugar$runit_complex
 	checkEquals( fx(x), list( 
-		Re = Re( x ), 
-		Im = Im( x ), 
-		Conj = Conj(x), 
-		Mod = Mod(x)
-		)
+		Re    = Re(x), 
+		Im    = Im(x), 
+		Conj  = Conj(x), 
+		Mod   = Mod(x), 
+		exp   = exp(x), 
+		log   = log(x), 
+		sqrt  = sqrt(x), 
+		cos   = cos(x),
+		sin   = sin(x),
+		tan   = tan(x), 
+		acos  = acos(x),
+		asin  = asin(x),
+		atan  = atan(x), 
+		# acosh = acosh(x),
+		asinh = asinh(x),
+		atanh = atanh(x), 
+		cosh  = cosh(x), 
+		sinh = sinh(x), 
+		tanh = tanh(x)
+		
+		) 
 	)
 }
 
@@ -1033,7 +1144,7 @@ test.sugar.tail <- function(){
 
 
 
-
+# matrix 
 
 
 			
@@ -1059,3 +1170,83 @@ test.sugar.diag <- function( ){
 		list( diag(x), diag(m), diag( outer( x, x, "+" ) ) ) ) 
 }
 
+
+
+
+
+# autogenerated sugar blocks
+
+test.sugar.gamma <- function(){
+	fx <- .rcpp.sugar$runit_gamma
+	x <- seq( 1, 5, by = .5 )
+	checkEquals( fx(x), 
+	 	list( 
+	  		"gamma"      = gamma(x), 
+	  		"lgamma"     = lgamma(x),
+	  		"digamma"    = digamma(x),
+	  		"trigamma"   = trigamma(x), 
+	  		"tetragamma" = psigamma(x, 2), 
+	  		"pentagamma" = psigamma(x, 3),
+	  		"factorial"  = factorial(x), 
+	  		"lfactorial" = lfactorial(x)
+	  	)
+	)
+}
+
+test.sugar.log1p <- function(){
+	x <- 10^-(1+2*1:9)
+	fx <- .rcpp.sugar$runit_log1p
+	checkEquals( fx(x), 
+		list( log1p = log1p(x), expm1 = expm1(x) ) )
+}
+
+test.sugar.choose <- function(){
+	fx <- .rcpp.sugar$runit_choose
+	checkEquals( fx(10:6,5:1), 
+		list( 
+			VV = choose( 10:6, 5:1), 
+			PV = choose( 10, 5:1 ), 
+			VP = choose( 10:6, 5 )
+		) )
+}
+
+test.sugar.lchoose <- function(){
+	fx <- .rcpp.sugar$runit_lchoose
+	checkEquals( fx(10:6,5:1), 
+		list( 
+			VV = lchoose( 10:6, 5:1), 
+			PV = lchoose( 10, 5:1 ), 
+			VP = lchoose( 10:6, 5 )
+		) )
+}
+
+test.sugar.beta <- function(){
+	fx <- .rcpp.sugar$runit_beta
+	checkEquals( fx(10:6,5:1), 
+		list( 
+			VV = beta( 10:6, 5:1), 
+			PV = beta( 10, 5:1 ), 
+			VP = beta( 10:6, 5 )
+		) )
+}
+
+test.sugar.lbeta <- function(){
+	fx <- .rcpp.sugar$runit_lbeta
+	checkEquals( fx(10:6,5:1), 
+		list( 
+			VV = lbeta( 10:6, 5:1), 
+			PV = lbeta( 10, 5:1 ), 
+			VP = lbeta( 10:6, 5 )
+		) )
+}
+
+test.sugar.psigamma <- function(){
+	fx <- .rcpp.sugar$runit_psigamma
+	checkEquals( fx(10:6,5:1), 
+		list( 
+			VV = psigamma( 10:6, 5:1), 
+			PV = psigamma( 10, 5:1 ), 
+			VP = psigamma( 10:6, 5 )
+		) )
+}
+
